# -*- coding: utf-8 -*-
import json
import os
import random
import re
import time
from datetime import datetime

import requests


class LianTongCheckIn:
    def __init__(self, check_item):
        self.check_item = check_item

    # 每日签到
    @staticmethod
    def daysign(session, liantong_data):
        headers = {
            "Host": "m.client.10010.com",
            "Accept": "*/*",
            "User-Agent": "ChinaUnicom4.x/810 CFNetwork/1209 Darwin/20.2.0",
            "Accept-Language": "zh-cn",
        }
        timestamp = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        data = f"reqtime={timestamp}&{liantong_data}"
        try:
            req1 = session.post(url="http://m.client.10010.com/mobileService/login.htm", headers=headers, data=data)
            a_token = req1.cookies.get("a_token")
            if a_token and req1.status_code == 200:
                phone = req1.json().get("default")
                req2 = session.post(
                    url="https://act.10010.com/SigninApp/signin/querySigninActivity.htm?token=" + a_token
                )
                if req2.status_code == 200:
                    req3 = session.post(
                        url="https://act.10010.com/SigninApp/signin/daySign", data="btnPouplePost".encode("utf-8")
                    )
                    if req3.status_code == 200:
                        session.post(url="https://act.10010.com/SigninApp/signin/getIntegral")
                        return f"帐号信息: {phone}"
            return f"帐号信息: 获取失败\n签到信息: 请检查参数是否过期"
        except Exception as e:
            return f"帐号信息: 获取失败\n签到信息: {e}"

    @staticmethod
    def get_encryptmobile(session):
        page = session.post(url="https://m.client.10010.com/dailylottery/static/textdl/userLogin")
        page.encoding = "utf-8"
        match = re.search(r"encryptmobile=\w+", page.text, flags=0)
        usernumber = match.group(0)[14:]
        return usernumber

    def choujiang(self, session):
        choujiang_msg = []
        try:
            numjsp = self.get_encryptmobile(session=session)
            session.post(url="https://m.client.10010.com/mobileservicequery/customerService/share/defaultShare.htm")
            session.get(
                url="https://m.client.10010.com/dailylottery/static/doubleball/firstpage?encryptmobile=" + numjsp
            )
            session.get(
                url="https://m.client.10010.com/dailylottery/static/outdailylottery/getRandomGoodsAndInfo?areaCode=076"
            )
            session.get(
                url="https://m.client.10010.com/dailylottery/static/active/findActivityInfo?areaCode=076&groupByType=&mobile="
                    + numjsp
            )
            for i in range(3):
                luck = session.post(
                    url="https://m.client.10010.com/dailylottery/static/doubleball/choujiang?usernumberofjsp=" + numjsp
                )
                luck.encoding = "utf-8"
                res = luck.json()
                choujiang_msg.append(res["RspMsg"])
        except Exception as e:
            choujiang_msg.append(str(e))
        return "天天抽奖: " + "；".join(choujiang_msg)

    def pointslottery_task(self, session):
        try:
            numjsp = self.get_encryptmobile(session=session)
            one_free = session.post(
                url="https://m.client.10010.com/dailylottery/static/integral/choujiang?usernumberofjsp=" + numjsp
            )
            one_free.encoding = "utf-8"
            res1 = one_free.json()
            jifeng_msg = res1["RspMsg"]
        except Exception as e:
            jifeng_msg = str(e)
        return "积分抽奖: " + jifeng_msg

    @staticmethod
    def gamecentersign_task(session):
        data1 = {"methodType": "signin", "clientVersion": "8.0100", "deviceType": "Android"}
        data2 = {"methodType": "iOSIntegralGet", "gameLevel": "1", "deviceType": "iOS"}
        try:
            game_center = session.post(url="https://m.client.10010.com/producGame_signin", data=data1)
            game_center.encoding = "utf-8"
            res = game_center.json()
            if res["respCode"] == "0000" and res["respDesc"] == "打卡并奖励成功":
                gamecentersign_msg = "游戏中心签到: 获得 " + str(res["currentIntegral"]) + " 积分"
            elif res["respCode"] == "0000":
                gamecentersign_msg = "游戏中心签到: " + res["respDesc"]
            else:
                print(res)
                gamecentersign_msg = "游戏中心签到: 失败"
            game_center_exp = session.post(url="https://m.client.10010.com/producGameApp", data=data2)
            game_center_exp.encoding = "utf-8"
            res1 = game_center_exp.json()
            if res1["code"] == "0000":
                gamecentersign_msg += "\n游戏频道打卡: 获得" + str(res1["integralNum"]) + "积分"
            else:
                gamecentersign_msg += "\n游戏频道打卡: " + res1["msg"]
        except Exception as e:
            gamecentersign_msg = "游戏中心签到：" + str(e)
        return gamecentersign_msg

    @staticmethod
    def day100integral_task(session):
        data = {"from": random.choice("123456789") + "".join(random.choice("0123456789") for i in range(10))}
        try:
            integral = session.post(
                url="https://m.client.10010.com/welfare-mall-front/mobile/integral/gettheintegral/v1", data=data
            )
            integral.encoding = "utf-8"
            res = integral.json()
            return "100定向积分: " + res["msg"]
        except Exception as e:
            return "100定向积分: " + str(e)

    @staticmethod
    def dongaopoints_task(session):
        data = {"from": random.choice("123456789") + "".join(random.choice("0123456789") for i in range(10))}
        trance = [0, 600, 300, 300, 300, 300, 300, 600]
        try:
            dongao_point = session.post(
                url="https://m.client.10010.com/welfare-mall-front/mobile/winterTwo/getIntegral/v1", data=data
            )
            dongao_point.encoding = "utf-8"
            res1 = dongao_point.json()
            dongao_num = session.post(
                url="https://m.client.10010.com/welfare-mall-front/mobile/winterTwo/winterTwoShop/v1", data=data
            )
            dongao_num.encoding = "utf-8"
            res2 = dongao_num.json()
            if res1["resdata"]["code"] == "0000":
                dongao_msg = (
                    "冬奥积分活动: " + res1["resdata"]["desc"] + "，" + str(trance[int(res2["resdata"]["signDays"])]) + "积分"
                )

            else:
                dongao_msg = "冬奥积分活动: " + res1["resdata"]["desc"] + "，" + res2["resdata"]["desc"]
        except Exception as e:
            dongao_msg = "冬奥积分活动: " + str(e)
        return dongao_msg

    @staticmethod
    def get_wotree_glowlist(session):
        response = session.post(url="https://m.client.10010.com/mactivity/arbordayJson/index.htm")
        res = response.json()
        return res["data"]["flowChangeList"]

    def wotree_task(self, session):
        try:
            flow_list = self.get_wotree_glowlist(session=session)
            for flow in flow_list:
                take_flow = session.get(
                    url="https://m.client.10010.com/mactivity/flowData/takeFlow.htm?flowId=" + flow["id"]
                )
                take_flow.encoding = "utf-8"
                res1 = take_flow.json()
                if res1["code"] == "0000":
                    print("沃之树-领流量: 4M 流量")
                else:
                    print("沃之树-领流量: 已领取过")
                time.sleep(1)
            session.post(url="https://m.client.10010.com/mactivity/arbordayJson/getChanceByIndex.htm?index=0")
            grow = session.post(url="https://m.client.10010.com/mactivity/arbordayJson/arbor/3/0/3/grow.htm")
            grow.encoding = "utf-8"
            res2 = grow.json()
            return "沃之树-浇水: 获得" + str(res2["data"]["addedValue"]) + "培养值" + "\n沃之树-领流量: 获得12M流量"
        except Exception as e:
            return "沃之树: " + str(e)

    @staticmethod
    def openbox_task(session):
        data1 = {"thirdUrl": "https://img.client.10010.com/shouyeyouxi/index.html#/youxibaoxiang"}
        data2 = {"methodType": "reward", "deviceType": "Android", "clientVersion": "8.0100", "isVideo": "Y"}
        data3 = {
            "methodType": "taskGetReward",
            "taskCenterId": "187",
            "clientVersion": "8.0100",
            "deviceType": "Android",
        }
        try:
            box = session.post(
                url="https://m.client.10010.com/mobileService/customer/getShareRedisInfo.htm", data=data1
            )
            box.encoding = "utf-8"
            watch_ad = session.post(url="https://m.client.10010.com/game_box", data=data2)
            watch_ad.encoding = "utf-8"
            draw_reward = session.post(url="https://m.client.10010.com/producGameTaskCenter", params=data3)
            draw_reward.encoding = "utf-8"
            res = draw_reward.json()
            if res["code"] == "0000":
                openbox_msg = "100M寻宝箱: " + "获得100M流量"
            else:
                openbox_msg = "100M寻宝箱: " + "任务失败"
        except Exception as e:
            openbox_msg = "100M寻宝箱:" + str(e)
        return openbox_msg

    @staticmethod
    def collectflow_task(session):
        liuliang = 0
        try:
            for i in range(3):
                watch_video = session.post(
                    url="https://act.10010.com/SigninApp/mySignin/addFlow", data={"stepflag": "22"}
                )
                watch_video.encoding = "utf-8"
                res1 = watch_video.json()
                if res1["reason"] == "00":
                    liuliang += int(res1.get("addNum", 0))
                elif res1["reason"] == "01":
                    print("4G流量包-看视频: 已完成")

            for i in range(3):
                download_prog = session.post(
                    url="https://act.10010.com/SigninApp/mySignin/addFlow", data={"stepflag": "23"}
                )
                download_prog.encoding = "utf-8"
                res2 = download_prog.json()
                if res2["reason"] == "00":
                    liuliang += int(res2.get("addNum", 0))
                elif res2["reason"] == "01":
                    print("4G流量包-下软件: 已完成")
        except Exception as e:
            return "4G流量包: " + str(e)
        return "4G流量包: 获得 " + str(liuliang) + "M"

    @staticmethod
    def dayoneg(session):
        try:
            # 观看视频任务
            session.post(url="https://act.10010.com/SigninApp/doTask/finishVideo")
            # 请求任务列表
            get_task_info = session.post(url="https://act.10010.com/SigninApp/doTask/getTaskInfo")
            get_task_info.encoding = "utf-8"
            get_prize = session.post(url="https://act.10010.com/SigninApp/doTask/getPrize")
            get_prize.encoding = "utf-8"
            session.post(url="https://act.10010.com/SigninApp/doTask/getTaskInfo")
            res1 = get_task_info.json()
            res2 = get_prize.json()
            if res1["data"]["taskInfo"]["status"] == "1":
                msg = "1G流量日包: " + res2["data"]["statusDesc"]
            else:
                msg = "1G流量日包: " + res1["data"]["taskInfo"]["btn"]
            time.sleep(1)
        except Exception as e:
            msg = "1G流量日包: 错误，" + str(e)
        return msg

    @staticmethod
    def user_info(session):
        resp = session.get(url="https://m.client.10010.com/mobileService/home/queryUserInfoSeven.htm?showType=3")
        user_info_msg = []
        for one in resp.json().get("data", {}).get("dataList", []):
            user_info_msg.append(one.get("remainTitle") + ": " + one.get("number") + one.get("unit"))
        return "\n".join(user_info_msg)

    def main(self):
        session = requests.session()
        liantong_data = self.check_item.get("data")
        sign_msg = self.daysign(session=session, liantong_data=liantong_data)
        dayoneg_msg = self.dayoneg(session=session)
        choujiang_msg = self.choujiang(session=session)
        pointslottery_msg = self.pointslottery_task(session=session)
        gamecentersign_msg = self.gamecentersign_task(session=session)
        day100integral_msg = self.day100integral_task(session=session)
        dongaopoints_msg = self.dongaopoints_task(session=session)
        wotree_msg = self.wotree_task(session=session)
        openbox_msg = self.openbox_task(session=session)
        collectflow_msg = self.collectflow_task(session=session)
        user_info_msg = self.user_info(session=session)
        msg = (
            f"{sign_msg}\n{user_info_msg}\n{choujiang_msg}\n{pointslottery_msg}\n"
            f"{gamecentersign_msg}\n{day100integral_msg}\n{dongaopoints_msg}\n{wotree_msg}\n"
            f"{openbox_msg}\n{collectflow_msg}\n{dayoneg_msg}"
        )
        return msg


if __name__ == "__main__":
    with open(
        os.path.join(os.path.dirname(os.path.dirname(__file__)), "config/config.json"), "r", encoding="utf-8"
    ) as f:
        datas = json.loads(f.read())
    _check_item = datas.get("LIANTONG_ACCOUNT_LIST", [])[0]
    print(LianTongCheckIn(check_item=_check_item).main())



# -*- coding: utf-8 -*-
import datetime
import json
import os

import requests
from requests import utils


class WPSCheckIn:
    def __init__(self, check_item):
        self.check_item = check_item

    @staticmethod
    def web_sign(session, sid):
        response = session.post(url="https://vip.wps.cn/sigin/do", headers={"sid": sid})
        resp = response.json()
        if resp["msg"] == "已完成签到":
            web_sign_msg = "网页签到: 今日已完成签到"
        elif resp["msg"] == "need_captcha":
            question_response = session.get(
                url="https://vip.wps.cn/checkcode/signin/question", headers={"sid": sid}
            ).json()
            answer_set = {
                "WPS会员全文检索",
                "100G",
                "WPS会员数据恢复",
                "WPS会员PDF转doc",
                "WPS会员PDF转图片",
                "WPS图片转PDF插件",
                "金山PDF转WORD",
                "WPS会员拍照转文字",
                "使用WPS会员修复",
                "WPS全文检索功能",
                "有，且无限次",
                "文档修复",
            }
            while question_response["data"]["multi_select"] == 1:
                question_response = session.get(
                    url="https://vip.wps.cn/checkcode/signin/question", headers={"sid": sid}
                ).json()
            answer_id = 3
            for i in range(4):
                opt = question_response["data"]["options"][i]
                if opt in answer_set:
                    answer_id = i + 1
                    break
            print("选项: {}".format(question_response["data"]["options"]))
            print("选择答案: {}".format(answer_id))
            answer_response = session.post(
                url="https://vip.wps.cn/sigin/do",
                headers={"sid": sid},
                data={"platform": 2, "answer": answer_id, "auth_type": "answer"},
            ).json()
            if answer_response["msg"] == "wrong answer":
                for i in range(4):
                    answer_response = session.post(
                        url="https://vip.wps.cn/sigin/do",
                        headers={"sid": sid},
                        data={"platform": 2, "answer": i + 1, "auth_type": "answer"},
                    ).json()
                    if answer_response["result"] == "ok":
                        break
            web_sign_msg = f"网页签到: 签到成功\n获得奖品{answer_response.get('gift_name')}\n领取地址: {answer_response.get('url')}"
        elif resp["result"] == "ok":
            web_sign_msg = "网页签到: {}".format(resp["msg"])
        else:
            web_sign_msg = "网页签到: {}".format(resp["msg"])
        return web_sign_msg

    def docer_sign(self, session, sid):
        response = session.post(url="https://zt.wps.cn/2018/docer_check_in/api/checkin_today", headers={"sid": sid})
        resp = response.json()
        if resp["result"] == "ok":
            docer_sign_msg = f'稻壳签到: {resp["result"]}'
        elif resp["msg"] == "recheckin":
            docer_sign_msg = "稻壳签到: 重复签到"
        else:
            return "稻壳签到: 签到失败"
        checkin_record_response = session.get(
            url="https://zt.wps.cn/2018/docer_check_in/api/checkin_record", headers={"sid": sid}
        ).json()
        docer_sign_msg += "\n本期连续签到: {} 天".format(checkin_record_response["data"]["max_days"])
        checkin_early_times_response = session.get(
            url="https://zt.wps.cn/2018/docer_check_in/api/checkin_early_times", headers={"sid": sid}
        ).json()
        docer_sign_msg += f"\n拥有补签卡: {checkin_early_times_response['data']} 张"
        max_days = checkin_record_response["data"]["max_days"]
        if checkin_early_times_response["data"] > 0 and len(checkin_record_response["data"]["records"]) > 0:
            max_days = self.docer_webpage_early_sign(
                session=session,
                sid=sid,
                checkinearly_times=checkin_early_times_response["data"],
                checkinrecord=checkin_record_response["data"]["records"],
                max_days=max_days,
            )
            docer_sign_msg += f"\n补签后连续签到: {max_days} 天"
        if len(checkin_record_response["data"]["records"]) > 0:
            gift_msg = self.docer_webpage_gift_receive(session=session, sid=sid, max_days=max_days)
            docer_sign_msg += f"\n{gift_msg}"
        return docer_sign_msg

    @staticmethod
    def docer_webpage_early_sign(session, sid, checkinearly_times, checkinrecord, max_days):
        now = datetime.datetime.utcnow()
        this_month_start = datetime.datetime(now.year, now.month, 1).date()
        checkin_earliestdate = datetime.datetime.strptime(checkinrecord[0]["checkin_date"], "%Y-%m-%d").date()
        for i in range(checkinearly_times):
            if checkin_earliestdate.day > this_month_start.day:
                checkin_date = checkin_earliestdate - datetime.timedelta(days=(i + 1))
                checkin_date = datetime.datetime.strptime(str(checkin_date), "%Y-%m-%d").strftime("%Y%m%d")
                session.post(
                    url="https://zt.wps.cn/2018/docer_check_in/api/checkin_early",
                    data={"date": checkin_date},
                    headers={"sid": sid},
                )
            else:
                if i == 0:
                    print("无需补签")
                    return max_days
                else:
                    print("使用补签卡{} 张".format(i))
                    resp = session.get(
                        url="https://zt.wps.cn/2018/docer_check_in/api/checkin_record", headers={"sid": sid}
                    ).json()
                    print("补签后连续签到: {}天".format(resp["data"]["max_days"]))
                    return resp["data"]["max_days"]
        print("使用补签卡{} 张".format(i))
        resp = session.get(url="https://zt.wps.cn/2018/docer_check_in/api/checkin_record", headers={"sid": sid}).json()
        return resp["data"]["max_days"]

    @staticmethod
    def docer_webpage_gift_receive(session, sid, max_days):
        gift_msg = ""
        resp = session.get(url="https://vip.wps.cn/userinfo", headers={"sid": sid}).json()
        memberid = [0]
        if len(resp["data"]["vip"]["enabled"]) > 0:
            for i in range(len(resp["data"]["vip"]["enabled"])):
                memberid.append(resp["data"]["vip"]["enabled"][i]["memberid"])
        resp = session.get(url="https://zt.wps.cn/2018/docer_check_in/api/reward_record", headers={"sid": sid}).json()
        reward_record_list = resp["data"]
        if len(reward_record_list) > 0:
            for i in reward_record_list:
                if i["reward_type"] == "vip" or i["reward_type"] == "code":
                    if (
                        int(i["limit_days"]) <= max_days
                        and int(i["limit_vip"]) in memberid
                        and i["status"] == "unreceived"
                    ):
                        receive_reward_resp = session.post(
                            url="https://zt.wps.cn/2018/docer_check_in/api/receive_reward",
                            data={"reward_id": i["id"], "receive_from": "pc_client"},
                            headers={"sid": sid},
                        )
                        gift_msg = "领取礼物: {} ".format(i["reward_name"])
                        if "reward_info" in receive_reward_resp.text:
                            resp1 = json.loads(receive_reward_resp.text)
                            gift_msg += "\n礼物信息: {}".format(resp1["data"]["reward_info"])
                        else:
                            gift_msg += "领取信息: {}".format(receive_reward_resp.text)
                    elif i["status"] == "received":
                        gift_msg = "已领取礼物: {} ".format(i["reward_name"])
                        if "reward_info" in i:
                            gift_msg += "\n礼物信息: {}".format(i["reward_info"])
        return gift_msg

    @staticmethod
    def miniprogram_sign(session, sid):
        resp = session.get(url="http://zt.wps.cn/2018/clock_in/api/clock_in", headers={"sid": sid}).json()
        if resp["msg"] == "已打卡":
            return f"小程序签到: {resp['msg']}"
        elif resp["msg"] == "未绑定手机":
            return f"小程序签到: {resp['msg']}"
        elif resp["msg"] == "前一天未报名":
            resp = session.get(url="http://zt.wps.cn/2018/clock_in/api/sign_up", headers={"sid": sid}).json()
            if resp["result"] == "ok":
                return "小程序报名: 已自动报名, 报名后第二天签到"
            else:
                return "小程序报名: 报名失败: 请手动报名, 报名后第二天签到"
        elif resp["msg"] == "答题未通过":
            resp = session.get(
                url="http://zt.wps.cn/2018/clock_in/api/get_question?member=wps", headers={"sid": sid}
            ).json()
            answer_set = {
                "WPS会员全文检索",
                "100G",
                "WPS会员数据恢复",
                "WPS会员PDF转doc",
                "WPS会员PDF转图片",
                "WPS图片转PDF插件",
                "金山PDF转WORD",
                "WPS会员拍照转文字",
                "使用WPS会员修复",
                "WPS全文检索功能",
                "有，且无限次",
                "文档修复",
            }
            while resp["data"]["multi_select"] == 1:
                resp = session.get(
                    url="http://zt.wps.cn/2018/clock_in/api/get_question?member=wps", headers={"sid": sid}
                ).json()
            answer_id = 3
            for i in range(4):
                opt = resp["data"]["options"][i]
                if opt in answer_set:
                    answer_id = i + 1
                    break
            print("选项: {}".format(resp["data"]["options"]))
            print("选择答案: {}".format(answer_id))
            resp = session.post(
                url="http://zt.wps.cn/2018/clock_in/api/answer?member=wps",
                headers={"sid": sid},
                data={"answer": answer_id},
            ).json()
            if resp["msg"] == "wrong answer":
                for i in range(4):
                    resp = session.post(
                        url="http://zt.wps.cn/2018/clock_in/api/answer?member=wps",
                        headers={"sid": sid},
                        data={"answer": i + 1},
                    ).json()
                    if resp["result"] == "ok":
                        break
            r = session.get(url="http://zt.wps.cn/2018/clock_in/api/clock_in?member=wps", headers={"sid": sid})
            return "小程序签到: {}".format(r.text)
        elif resp["msg"] == "ParamData Empty":
            session.get(url="http://zt.wps.cn/2018/clock_in/api/sign_up", headers={"sid": sid}).json()
            return f"小程序签到: {resp['msg']}"
        elif resp["msg"] == "不在打卡时间内":
            print("签到失败: 不在打卡时间内")
            resp = session.get(url="http://zt.wps.cn/2018/clock_in/api/sign_up", headers={"sid": sid}).json()
            if resp["result"] == "ok":
                return "小程序签到: 已自动报名, 报名后请设置在规定时间内签到"
            else:
                return "小程序签到: 报名失败: 请手动报名, 报名后第二天签到"
        elif resp["result"] == "error":
            signup_url = "http://zt.wps.cn/2018/clock_in/api/sign_up"
            resp = session.get(signup_url, headers={"sid": sid}).json()
            if resp["result"] == "ok":
                return "小程序签到: 已自动报名, 报名后请设置在规定时间内签到"
            else:
                return "小程序签到: 报名失败: 请手动报名, 报名后第二天签到"
        # member_url = "https://zt.wps.cn/2018/clock_in/api/get_data?member=wps"
        # resp = session.get(member_url, headers={"sid": sid})
        # total_add_day = re.search(r'"total_add_day":(\d+)', resp.text).group(1)
        # print("小程序打卡中累计获得会员: {} 天".format(total_add_day))

    @staticmethod
    def user_info(session, sid):
        resp1 = session.post(url="https://vip.wps.cn/2019/user/summary", headers={"sid": sid}).json()
        resp = session.get(url="https://vip.wps.cn/userinfo", headers={"sid": sid}).json()
        nickname = resp["data"]["nickname"]
        userid = resp["data"]["userid"]
        user_info = f'用户名称: {nickname}\n会员积分: {resp1["data"]["integral"]}\n稻米数量: {resp1["data"]["wealth"]}'
        if len(resp["data"]["vip"]["enabled"]) > 0:
            for one_vip in resp["data"]["vip"]["enabled"]:
                user_info += f"\n{one_vip.get('name')}: {datetime.datetime.fromtimestamp(one_vip.get('expire_time')).strftime('%Y-%m-%d %H:%M:%S')}"
        return user_info, userid

    def main(self):
        wps_cookie = {item.split("=")[0]: item.split("=")[1] for item in self.check_item.get("wps_cookie").split("; ")}
        session = requests.session()
        requests.utils.add_dict_to_cookiejar(session.cookies, wps_cookie)
        session.headers.update(
            {
                "Accept": "*/*",
                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.182 Safari/537.36 Edg/88.0.705.74",
                "X-Requested-With": "XMLHttpRequest",
                "Origin": "http://www.wpsmembers.cn",
                "Referer": "http://www.wpsmembers.cn/",
                "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
            }
        )
        sid = wps_cookie.get("wps_sid")
        web_sign_msg = self.web_sign(session=session, sid=sid)
        docer_sign_msg = self.docer_sign(session=session, sid=sid)
        miniprogram_sign_msg = self.miniprogram_sign(session=session, sid=sid)
        user_info_msg, userid = self.user_info(session=session, sid=sid)
        msg = f"{user_info_msg}\n{web_sign_msg}\n{docer_sign_msg}\n{miniprogram_sign_msg}"
        return msg


if __name__ == "__main__":
    with open(
        os.path.join(os.path.dirname(os.path.dirname(__file__)), "config/config.json"), "r", encoding="utf-8"
    ) as f:
        datas = json.loads(f.read())
    _check_item = datas.get("WPS_COOKIE_LIST", [])[0]
    print(WPSCheckIn(check_item=_check_item).main())
